@@ -281,10 +281,11 @@ read_psv <- function(fn,names=NULL) {
 read_rep <- function(fn,names=NULL,warn_nonstd_rep=TRUE) {
     fn <- tolower(fn)
     fnx <- paste(fn,"rep",sep=".")
+    if (!file.exists(fnx)) return(NULL)
     ## check format!
     rr <- readLines(fnx)
     ## FIXME: could test for numerics more carefully ...
-    numLines <- grepl("^[0-9. e]",rr)
+    numLines <- grepl("^[0-9. e+-]*$",rr)
     commentLines <- grepl("^#",rr)
     stringLines <- grepl("^[[:alpha:]]*$",rr)
     if (!all(numLines | commentLines | stringLines) || !commentLines[1]) {
